@@ -5,7 +5,7 @@
 double get_random()
 {
     static std::default_random_engine e;
-    //e. seed (5);
+    e. seed (5);
     static std::uniform_real_distribution<double> dis(0.0, 0.1); // rage 0 - 1
     return dis(e);
 }
